@@ -42,8 +42,8 @@ class BasicSettings : public QWidget
     Q_OBJECT
 
 public:
-    explicit BasicSettings(LXQt::Settings *settings, QWidget *parent = 0);
-    ~BasicSettings();
+    explicit BasicSettings(LXQt::Settings *settings, QWidget *parent = nullptr);
+    ~BasicSettings() override;
 
 signals:
     void needRestart();
