@@ -26,7 +26,7 @@
     <message>
         <location filename="../autostartedit.ui" line="57"/>
         <source>Wait for system tray</source>
-        <translation>システムトレイに入れる</translation>
+        <translation>システムトレイの起動を待つ</translation>
     </message>
     <message>
         <location filename="../autostartedit.cpp" line="61"/>
@@ -39,12 +39,12 @@
     <message>
         <location filename="../autostartmodel.cpp" line="193"/>
         <source>Global Autostart</source>
-        <translation>全体的な自動起動</translation>
+        <translation>全体の自動起動</translation>
     </message>
     <message>
         <location filename="../autostartmodel.cpp" line="195"/>
         <source>LXQt Autostart</source>
-        <translation>LXQt 自動起動</translation>
+        <translation>LXQt の自動起動</translation>
     </message>
     <message>
         <location filename="../autostartmodel.cpp" line="213"/>
@@ -77,7 +77,7 @@
     <message>
         <location filename="../autostartpage.ui" line="44"/>
         <source>Application Autostart</source>
-        <translation>アプリケーション自動起動</translation>
+        <translation>アプリケーションの自動起動</translation>
     </message>
     <message>
         <location filename="../autostartpage.cpp" line="143"/>
@@ -87,7 +87,7 @@
     <message>
         <location filename="../autostartpage.cpp" line="143"/>
         <source>File &apos;%1&apos; already exists!</source>
-        <translation>ファイル &apos;%1&apos; は既にあります！</translation>
+        <translation>ファイル &apos;%1&apos; が既に存在しています！</translation>
     </message>
 </context>
 <context>
@@ -115,7 +115,7 @@
     <message>
         <location filename="../basicsettings.ui" line="65"/>
         <source>Start</source>
-        <translation>開始</translation>
+        <translation>実行</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="72"/>
@@ -135,7 +135,7 @@
     <message>
         <location filename="../basicsettings.ui" line="124"/>
         <source>Lock screen before suspending/hibernating</source>
-        <translation>サスペンド/ハイバネートの前に画面をロックする&#x3000;&#x3000;&#x3000;&#x3000;&#x3000;&#x3000;</translation>
+        <translation>サスペンド/ハイバネートの前に画面をロックする　　　　　　</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="131"/>
@@ -237,7 +237,7 @@
     <message>
         <location filename="../userlocationspage.cpp" line="185"/>
         <source>LXQt Session Settings - User Directories</source>
-        <translation>LXQt セッションの設定--ユーザーディレクトリ</translation>
+        <translation>LXQt セッションの設定 - ユーザーディレクトリ</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="186"/>
@@ -275,7 +275,7 @@
     <message>
         <location filename="../userlocationspage.cpp" line="67"/>
         <source>Documents</source>
-        <translation>文書</translation>
+        <translation>ドキュメント</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="68"/>
@@ -290,47 +290,47 @@
     <message>
         <location filename="../userlocationspage.cpp" line="70"/>
         <source>Videos</source>
-        <translation>動画</translation>
+        <translation>ビデオ</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="73"/>
         <source>Contains all the files which you see on your desktop</source>
-        <translation>デスクトップ上で見ることができるファイルを全て含む</translation>
+        <translation>デスクトップ上で見れる全てのファイルを含みます</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="74"/>
         <source>Default folder to save your downloaded files</source>
-        <translation>ダウンロードしたファイルを保存する既定のフォルダー</translation>
+        <translation>ダウンロードしたファイルを保存する既定のフォルダーです</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="75"/>
         <source>Default folder to load or save templates from or to</source>
-        <translation>テンプレートファイルを保存する既定のフォルダー</translation>
+        <translation>テンプレートファイルを保存する既定のフォルダーです</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="76"/>
         <source>Default folder to publicly share your files</source>
-        <translation>共有ファイルを公開する際の既定のフォルダー</translation>
+        <translation>共有ファイルを公開する既定のフォルダーです</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="77"/>
         <source>Default folder to load or save documents from or to</source>
-        <translation>文書ファイルを保存する既定のフォルダー</translation>
+        <translation>文書ファイルを保存する既定のフォルダーです</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="78"/>
         <source>Default folder to load or save music from or to</source>
-        <translation>音楽ファイルを保存する既定のフォルダー</translation>
+        <translation>音楽ファイルを保存する既定のフォルダーです</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="79"/>
         <source>Default folder to load or save pictures from or to</source>
-        <translation>画像ファイルを保存する既定のフォルダー</translation>
+        <translation>画像ファイルを保存する既定のフォルダーです</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="80"/>
         <source>Default folder to load or save videos from or to</source>
-        <translation>動画ファイルを保存する既定のフォルダー</translation>
+        <translation>動画ファイルを保存する既定のフォルダーです</translation>
     </message>
 </context>
 </TS>
