@@ -16,7 +16,7 @@
     <message>
         <location filename="../autostartedit.ui" line="27"/>
         <source>Search...</source>
-        <translation>Zoeken...</translation>
+        <translation>Zoeken…</translation>
     </message>
     <message>
         <location filename="../autostartedit.ui" line="47"/>
@@ -26,12 +26,12 @@
     <message>
         <location filename="../autostartedit.ui" line="57"/>
         <source>Wait for system tray</source>
-        <translation>Wacht op systeemvak</translation>
+        <translation>Wachten op systeemvak</translation>
     </message>
     <message>
         <location filename="../autostartedit.cpp" line="61"/>
         <source>Select Application</source>
-        <translation>Kies toepassing</translation>
+        <translation>Kies een programma</translation>
     </message>
 </context>
 <context>
@@ -39,12 +39,12 @@
     <message>
         <location filename="../autostartmodel.cpp" line="193"/>
         <source>Global Autostart</source>
-        <translation>Systeembrede automatische start</translation>
+        <translation>Automatisch opstarten met systeem</translation>
     </message>
     <message>
         <location filename="../autostartmodel.cpp" line="195"/>
         <source>LXQt Autostart</source>
-        <translation>LXQt Autostart</translation>
+        <translation>LXQt automatisch opstarten</translation>
     </message>
     <message>
         <location filename="../autostartmodel.cpp" line="213"/>
@@ -62,7 +62,7 @@
     <message>
         <location filename="../autostartpage.ui" line="17"/>
         <source>Delete</source>
-        <translation>Wissen</translation>
+        <translation>Verwijderen</translation>
     </message>
     <message>
         <location filename="../autostartpage.ui" line="24"/>
@@ -77,17 +77,17 @@
     <message>
         <location filename="../autostartpage.ui" line="44"/>
         <source>Application Autostart</source>
-        <translation>Automatische start van toepassingen</translation>
+        <translation>Programma&apos;s automatisch opstarten</translation>
     </message>
     <message>
         <location filename="../autostartpage.cpp" line="143"/>
         <source>Error</source>
-        <translation>Fout</translation>
+        <translation>Foutmelding</translation>
     </message>
     <message>
         <location filename="../autostartpage.cpp" line="143"/>
         <source>File &apos;%1&apos; already exists!</source>
-        <translation>Bestand &apos;%1&apos; bestaat reeds!</translation>
+        <translation>&apos;%1&apos; bestaat al!</translation>
     </message>
 </context>
 <context>
@@ -95,7 +95,7 @@
     <message>
         <location filename="../basicsettings.ui" line="23"/>
         <source>Basic Settings</source>
-        <translation>Basisinstellingen</translation>
+        <translation>Algemene instellingen</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="30"/>
@@ -105,7 +105,7 @@
     <message>
         <location filename="../basicsettings.ui" line="49"/>
         <source>Search...</source>
-        <translation>Zoeken...</translation>
+        <translation>Zoeken…</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="59"/>
@@ -115,22 +115,22 @@
     <message>
         <location filename="../basicsettings.ui" line="65"/>
         <source>Start</source>
-        <translation>Start</translation>
+        <translation>Starten</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="72"/>
         <source>Stop</source>
-        <translation>Stop</translation>
+        <translation>Stoppen</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="124"/>
         <source>Lock screen before suspending/hibernating</source>
-        <translation>Vergrendel scherm alvorens in pauzestand/slaapstand te gaan</translation>
+        <translation>Scherm vergrendelen alvorens in pauze- of slaapstand te gaan</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="131"/>
         <source>Suspend/hibernate after lock delay:</source>
-        <translation>Slaapstand/winterslaap na vergrendelvertraging:</translation>
+        <translation>Pauzestand/Winterstand na vergrendelvertraging:</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="144"/>
@@ -150,7 +150,7 @@
     <message>
         <location filename="../basicsettings.ui" line="117"/>
         <source>Ask for confirmation to leave session</source>
-        <translation>Vraag om bevestiging voor het beëindigen van de sessie</translation>
+        <translation>Vragen om bevestiging bij beëindigen van sessie</translation>
     </message>
 </context>
 <context>
@@ -163,17 +163,17 @@
     <message>
         <location filename="../environmentpage.ui" line="24"/>
         <source>Delete</source>
-        <translation>Wissen</translation>
+        <translation>Verwijderen</translation>
     </message>
     <message>
         <location filename="../environmentpage.ui" line="50"/>
         <source>Environment Variables (Advanced)</source>
-        <translation>Omgevingsvariabelen (geavanceerd)</translation>
+        <translation>Omgevingsvariabelen (voor ervaren gebruikers)</translation>
     </message>
     <message>
         <location filename="../environmentpage.ui" line="61"/>
         <source>Variable Name</source>
-        <translation>Naam van variabele</translation>
+        <translation>Naam van variabel</translation>
     </message>
     <message>
         <location filename="../environmentpage.ui" line="66"/>
@@ -186,7 +186,7 @@
     <message>
         <location filename="../modulemodel.cpp" line="87"/>
         <source>Running</source>
-        <translation>Draaiend</translation>
+        <translation>Actief</translation>
     </message>
 </context>
 <context>
@@ -199,7 +199,7 @@
     <message>
         <location filename="../sessionconfigwindow.cpp" line="47"/>
         <source>Basic Settings</source>
-        <translation>Basisinstellingen</translation>
+        <translation>Algemene instellingen</translation>
     </message>
     <message>
         <location filename="../sessionconfigwindow.cpp" line="53"/>
@@ -209,12 +209,12 @@
     <message>
         <location filename="../sessionconfigwindow.cpp" line="59"/>
         <source>Autostart</source>
-        <translation>Autostart</translation>
+        <translation>Automatisch opstarten</translation>
     </message>
     <message>
         <location filename="../sessionconfigwindow.cpp" line="65"/>
         <source>Environment (Advanced)</source>
-        <translation>Omgeving (geavanceerd)</translation>
+        <translation>Omgeving (voor ervaren gebruikers)</translation>
     </message>
     <message>
         <location filename="../sessionconfigwindow.cpp" line="87"/>
@@ -224,7 +224,7 @@
     <message>
         <location filename="../sessionconfigwindow.cpp" line="88"/>
         <source>Some settings will not take effect until the next log in.</source>
-        <translation>Sommige instellingen zullen pas effect hebben na de volgende aanmelding.</translation>
+        <translation>Sommige instellingen worden pas toegepast na de volgende aanmelding.</translation>
     </message>
 </context>
 <context>
@@ -232,22 +232,22 @@
     <message>
         <location filename="../userlocationspage.cpp" line="116"/>
         <source>Locations for Personal Files</source>
-        <translation>Opslaglocaties voor persoonlijke bestanden</translation>
+        <translation>Opslaglocaties van persoonlijke bestanden</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="185"/>
         <source>LXQt Session Settings - User Directories</source>
-        <translation>LXQt-sessie-instellingen - gebruikersmappen</translation>
+        <translation>LXQt-sessie-instellingen - Gebruikersmappen</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="186"/>
         <source>An error ocurred while applying the settings for the %1 location</source>
-        <translation>Er is een fout opgetreden bij het toepassen van de instellingen voor de locatie %1</translation>
+        <translation>Er is een fout opgetreden bij het toepassen van de instellingen van de locatie &apos;%1&apos;</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="202"/>
         <source>Choose Location</source>
-        <translation>Opslaglocatie kiezen</translation>
+        <translation>Kies een locatie</translation>
     </message>
 </context>
 <context>
@@ -270,7 +270,7 @@
     <message>
         <location filename="../userlocationspage.cpp" line="66"/>
         <source>Public Share</source>
-        <translation>Publieke map</translation>
+        <translation>Openbare map</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="67"/>
@@ -295,42 +295,42 @@
     <message>
         <location filename="../userlocationspage.cpp" line="73"/>
         <source>Contains all the files which you see on your desktop</source>
-        <translation>Bevat alle bestanden die u ziet op uw bureaublad</translation>
+        <translation>Bevat alle bestanden die op uw bureaublad aantreft</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="74"/>
         <source>Default folder to save your downloaded files</source>
-        <translation>Standaardmap voor binnengehaalde bestanden</translation>
+        <translation>Standaardmap met gedownloade bestanden</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="75"/>
         <source>Default folder to load or save templates from or to</source>
-        <translation>Standaardmap voor sjablonen</translation>
+        <translation>Standaardmap met sjablonen</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="76"/>
         <source>Default folder to publicly share your files</source>
-        <translation>Standaardmap voor publiekelijk gedeelde bestanden</translation>
+        <translation>Standaardmap met openbaar gedeelde bestanden</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="77"/>
         <source>Default folder to load or save documents from or to</source>
-        <translation>Standaardmap voor documenten</translation>
+        <translation>Standaardmap met documenten</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="78"/>
         <source>Default folder to load or save music from or to</source>
-        <translation>Standaardmap om muziek in op te slaan of om van te laden</translation>
+        <translation>Standaardmap met muziek</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="79"/>
         <source>Default folder to load or save pictures from or to</source>
-        <translation>Standaardmap voor afbeeldingen</translation>
+        <translation>Standaardmap met afbeeldingen/foto&apos;s</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="80"/>
         <source>Default folder to load or save videos from or to</source>
-        <translation>Standaardmap voor video&apos;s</translation>
+        <translation>Standaardmap met video&apos;s</translation>
     </message>
 </context>
 </TS>
