@@ -110,27 +110,27 @@
     <message>
         <location filename="../basicsettings.ui" line="111"/>
         <source>Leave Session</source>
-        <translation>Вийти з сесії</translation>
+        <translation>Вийти з сеансу</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="117"/>
         <source>Ask for confirmation to leave session</source>
-        <translation>Запитати про підтвердження виходу з сесії</translation>
+        <translation>Запитувати підтвердження про вихід з сеансу</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="124"/>
         <source>Lock screen before suspending/hibernating</source>
-        <translation type="unfinished"></translation>
+        <translation>Блокувати екран перед переходом з режим зупинення/сну</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="131"/>
         <source>Suspend/hibernate after lock delay:</source>
-        <translation type="unfinished"></translation>
+        <translation>Перехід в режим зупинення/сну після блокування через:</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="144"/>
         <source> ms</source>
-        <translation type="unfinished"></translation>
+        <translation> мс</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="23"/>
@@ -224,7 +224,7 @@
     <message>
         <location filename="../sessionconfigwindow.cpp" line="88"/>
         <source>Some settings will not take effect until the next log in.</source>
-        <translation>Деякі налаштування застосуються після наступного входу. </translation>
+        <translation>Деякі налаштування застосуються після наступного входу.</translation>
     </message>
 </context>
 <context>
@@ -285,7 +285,7 @@
     <message>
         <location filename="../userlocationspage.cpp" line="69"/>
         <source>Pictures</source>
-        <translation>Малюнки</translation>
+        <translation>Зображення</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="70"/>
@@ -295,7 +295,7 @@
     <message>
         <location filename="../userlocationspage.cpp" line="73"/>
         <source>Contains all the files which you see on your desktop</source>
-        <translation>Містить всі файли, які Ви бачите на Вашій стільниці</translation>
+        <translation>Містить всі файли, які ви бачите на своїй стільниці</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="74"/>
@@ -310,7 +310,7 @@
     <message>
         <location filename="../userlocationspage.cpp" line="76"/>
         <source>Default folder to publicly share your files</source>
-        <translation>Типова тека для публічно доступних Ваших файлів</translation>
+        <translation>Типова тека для ваших загальнодоступних файлів</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="77"/>
@@ -320,12 +320,12 @@
     <message>
         <location filename="../userlocationspage.cpp" line="78"/>
         <source>Default folder to load or save music from or to</source>
-        <translation type="unfinished"></translation>
+        <translation>Типова тека для завантаження або збереження музики з або до</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="79"/>
         <source>Default folder to load or save pictures from or to</source>
-        <translation>Типова тека для завантаження або збереження малюнків з або до</translation>
+        <translation>Типова тека для завантаження або збереження зображень з або до</translation>
     </message>
     <message>
         <location filename="../userlocationspage.cpp" line="80"/>
