@@ -130,15 +130,18 @@ UserLocationsPage::UserLocationsPage(QWidget *parent)
 
         QToolButton *button = new QToolButton(this);
         button->setIcon(XdgIcon::fromTheme(QStringLiteral("folder")));
-        connect(button, SIGNAL(clicked()), d->signalMapper, SLOT(map()));
+        connect(button, &QToolButton::clicked, d->signalMapper, QOverload<>::of(&QSignalMapper::map));
         d->signalMapper->setMapping(button, i);
 
         gridLayout->addWidget(label, row, 0);
         gridLayout->addWidget(edit, row, 1);
         gridLayout->addWidget(button, row, 2);
     }
-    connect(d->signalMapper, SIGNAL(mapped(int)),
-            this, SLOT(clicked(int)));
+#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
+    connect(d->signalMapper, &QSignalMapper::mappedInt, this, &UserLocationsPage::clicked);
+#else
+    connect(d->signalMapper, QOverload<int>::of(&QSignalMapper::mapped), this, &UserLocationsPage::clicked);
+#endif
 
     QSpacerItem *verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum,
                                                   QSizePolicy::Expanding);
