@@ -11,7 +11,7 @@
     <message>
         <location filename="../leavedialog.ui" line="71"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;What do you want the computer to do?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Що б Ви бажали щоб комп&apos;ютер зробив?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Що ви бажаєте виконувати на комп&apos;ютері?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="../leavedialog.cpp" line="55"/>
@@ -26,7 +26,7 @@
     <message>
         <location filename="../leavedialog.cpp" line="60"/>
         <source>Shutdown</source>
-        <translation>Виключити</translation>
+        <translation>Вимкнути</translation>
     </message>
     <message>
         <location filename="../leavedialog.cpp" line="65"/>
@@ -36,7 +36,7 @@
     <message>
         <location filename="../leavedialog.cpp" line="70"/>
         <source>Lock screen</source>
-        <translation>Замкнути екран</translation>
+        <translation>Заблокувати екран</translation>
     </message>
     <message>
         <location filename="../leavedialog.cpp" line="78"/>
@@ -46,7 +46,7 @@
     <message>
         <location filename="../leavedialog.ui" line="51"/>
         <source>Cancel</source>
-        <translation>Відмінити</translation>
+        <translation>Скасувати</translation>
     </message>
 </context>
 <context>
@@ -59,7 +59,7 @@
     <message>
         <location filename="../main.cpp" line="63"/>
         <source>Lockscreen.</source>
-        <translation>Замкнути екран.</translation>
+        <translation>Заблокувати екран.</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="66"/>
@@ -74,7 +74,7 @@
     <message>
         <location filename="../main.cpp" line="72"/>
         <source>Shutdown.</source>
-        <translation>Виключити.</translation>
+        <translation>Вимкнути.</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="75"/>
