@@ -66,10 +66,11 @@ LXQtModuleManager::LXQtModuleManager(QObject* parent)
       mTrayStarted(false),
       mWaitLoop(nullptr)
 {
-    connect(mThemeWatcher, SIGNAL(directoryChanged(QString)), SLOT(themeFolderChanged(QString)));
-    connect(LXQt::Settings::globalSettings(), SIGNAL(lxqtThemeChanged()), SLOT(themeChanged()));
+    connect(mThemeWatcher, &QFileSystemWatcher::directoryChanged, this, &LXQtModuleManager::themeFolderChanged);
+    connect(LXQt::Settings::globalSettings(), &LXQt::GlobalSettings::lxqtThemeChanged, this, &LXQtModuleManager::themeChanged);
 
     qApp->installNativeEventFilter(this);
+    mProcReaper.start();
 }
 
 void LXQtModuleManager::setWindowManager(const QString & windowManager)
@@ -198,17 +199,7 @@ void LXQtModuleManager::startWm(LXQt::Settings *settings)
         settings->sync();
     }
 
-    if (QFileInfo(mWindowManager).baseName() == QL1S("openbox"))
-    {
-        // Default settings of openbox are copied by lxqt-session/startlxqt.in
-        QString openboxSettingsPath = XdgDirs::configHome() + QSL("/openbox/lxqt-rc.xml");
-        QStringList args;
-        if(QFileInfo::exists(openboxSettingsPath))
-            args << QSL("--config-file") << openboxSettingsPath;
-        mWmProcess->start(mWindowManager, args);
-    }
-    else
-        mWmProcess->start(mWindowManager, QStringList());
+    mWmProcess->start(mWindowManager, QStringList());
     
     // other autostart apps will be handled after the WM becomes available
 
@@ -238,14 +229,13 @@ void LXQtModuleManager::startProcess(const XdgDesktopFile& file)
         return;
     }
     LXQtModule* proc = new LXQtModule(file, this);
-    connect(proc, SIGNAL(moduleStateChanged(QString,bool)), this, SIGNAL(moduleStateChanged(QString,bool)));
+    connect(proc, &LXQtModule::moduleStateChanged, this, &LXQtModuleManager::moduleStateChanged);
     proc->start();
 
     QString name = QFileInfo(file.fileName()).fileName();
     mNameMap[name] = proc;
 
-    connect(proc, SIGNAL(finished(int, QProcess::ExitStatus)),
-            this, SLOT(restartModules(int, QProcess::ExitStatus)));
+    connect(proc, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished), this, &LXQtModuleManager::restartModules);
 }
 
 void LXQtModuleManager::startProcess(const QString& name)
@@ -341,7 +331,7 @@ LXQtModuleManager::~LXQtModuleManager()
         i.next();
 
         auto p = i.value();
-        disconnect(p, SIGNAL(finished(int, QProcess::ExitStatus)), nullptr, nullptr);
+        disconnect(p);
 
         delete p;
         mNameMap[i.key()] = nullptr;
@@ -376,6 +366,9 @@ void LXQtModuleManager::logout(bool doExit)
         }
     }
 
+    // terminate all possible children except WM
+    mProcReaper.stop({mWmProcess->processId()});
+
     mWmProcess->terminate();
     if (mWmProcess->state() != QProcess::NotRunning && !mWmProcess->waitForFinished(2000))
     {
@@ -468,7 +461,7 @@ LXQtModule::LXQtModule(const XdgDesktopFile& file, QObject* parent) :
     mIsTerminating(false)
 {
     QProcess::setProcessChannelMode(QProcess::ForwardedChannels);
-    connect(this, SIGNAL(stateChanged(QProcess::ProcessState)), SLOT(updateState(QProcess::ProcessState)));
+    connect(this, &LXQtModule::stateChanged, this, &LXQtModule::updateState);
 }
 
 void LXQtModule::start()
