@@ -36,6 +36,7 @@
 #include <XdgDesktopFile>
 #include <QEventLoop>
 #include <time.h>
+#include "procreaper.h"
 
 class LXQtModule;
 namespace LXQt {
@@ -142,6 +143,8 @@ private:
     bool mTrayStarted;
     QEventLoop* mWaitLoop;
 
+    ProcReaper mProcReaper;
+
 private slots:
 
     /*! \brief this slot is called by the QProcesses if they end.
