@@ -85,16 +85,16 @@ bool SessionApplication::startup()
     QTimer * dev_timer = new QTimer{this}; //will be released upon our destruction
     dev_timer->setSingleShot(true);
     dev_timer->setInterval(500); //give some time to xorg... we need to reset keyboard afterwards
-    connect(dev_timer, &QTimer::timeout, [this]
+    connect(dev_timer, &QTimer::timeout, this, [this]
             {
                 //XXX: is this a race? (because settings can be currently changed by lxqt-config-input)
                 //     but with such a little probablity we can live...
                 LXQt::Settings settings(configName);
                 loadKeyboardSettings(settings);
             });
-    connect(dev_notifier, &UdevNotifier::deviceAdded, [this, dev_timer] (QString device)
+    connect(dev_notifier, &UdevNotifier::deviceAdded, this, [this, dev_timer] (QString device)
             {
-                qCWarning(SESSION) << QStringLiteral("Session '%1', new input device '%2', keyboard setting will be (optionaly) reloaded...").arg(configName).arg(device);
+                qCWarning(SESSION) << QStringLiteral("Session '%1', new input device '%2', keyboard setting will be (optionaly) reloaded...").arg(configName,device);
                 dev_timer->start();
             });
     // Detect display connection:
@@ -103,9 +103,9 @@ bool SessionApplication::startup()
     // # echo detect > status
     // at /sys/devices/pciXXX/drm/cardX/cardX-XXX
     UdevNotifier *dev_notifier_drm_subsystem = new UdevNotifier(QStringLiteral("drm"), this); //will be released upon our destruction
-    connect(dev_notifier_drm_subsystem, &UdevNotifier::deviceChanged, [this] (QString device)
+    connect(dev_notifier_drm_subsystem, &UdevNotifier::deviceChanged, this, [this] (QString device)
             {
-                qCWarning(SESSION) << QStringLiteral("Session '%1': display device '%2'").arg(configName).arg(device);
+                qCWarning(SESSION) << QStringLiteral("Session '%1': display device '%2'").arg(configName,device);
                 QProcess::startDetached(QStringLiteral("lxqt-config-monitor"), QStringList(QStringLiteral("-l")));
             });
 #endif
@@ -181,7 +181,8 @@ void SessionApplication::loadKeyboardSettings(LXQt::Settings& settings)
     settings.beginGroup(QSL("Keyboard"));
     XKeyboardControl values;
     /* Keyboard settings */
-    unsigned int delay, interval;
+    unsigned int delay = 0;
+    unsigned int interval = 0;
     if(XkbGetAutoRepeatRate(QX11Info::display(), XkbUseCoreKbd, (unsigned int*) &delay, (unsigned int*) &interval))
     {
         delay = settings.value(QSL("delay"), delay).toUInt();
@@ -286,8 +287,10 @@ void SessionApplication::loadFontSettings(LXQt::Settings& settings)
 #define DEFAULT_PTR_MAP_SIZE 128
 void SessionApplication::setLeftHandedMouse(bool mouse_left_handed)
 {
-    unsigned char *buttons, *more_buttons;
-    int n_buttons, i;
+    unsigned char *buttons = nullptr;
+    unsigned char *more_buttons = nullptr;
+    int n_buttons = 0;
+    int i = 0;
     int idx_1 = 0, idx_3 = 1;
 
     buttons = (unsigned char*)malloc(DEFAULT_PTR_MAP_SIZE);
