@@ -2,59 +2,54 @@
 <!DOCTYPE TS>
 <TS version="2.1" language="eo">
 <context>
-    <name>LxQtModuleManager</name>
+    <name>LXQtModuleManager</name>
     <message>
-        <source>LxQt Session Crash Report</source>
-        <translation type="vanished">Raporto de kolapsoj de LxQt-seancoj</translation>
-    </message>
-    <message>
-        <source>Application &apos;%1&apos; crashed too many times. Its autorestart has been disabled for current session.</source>
-        <translation type="vanished">Aplikaĵo &apos;%1&apos; kolapsis tro ofte. Sia aŭtomata restarto estis malŝaltita por ĉi tiu seanco.</translation>
-    </message>
-    <message>
-        <location filename="../src/lxqtmodman.cpp" line="289"/>
+        <location filename="../src/lxqtmodman.cpp" line="311"/>
         <source>Crash Report</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/lxqtmodman.cpp" line="290"/>
+        <location filename="../src/lxqtmodman.cpp" line="312"/>
         <source>&lt;b&gt;%1&lt;/b&gt; crashed too many times. Its autorestart has been disabled until next login.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>SessionApplication</name>
+    <message>
+        <location filename="../src/main.cpp" line="62"/>
+        <source>Configuration file path.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/main.cpp" line="62"/>
+        <location filename="../src/main.cpp" line="63"/>
+        <source>file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/main.cpp" line="63"/>
+        <source>Window manager to use.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>WmSelectDialog</name>
     <message>
+        <location filename="../src/wmselectdialog.ui" line="14"/>
         <source>Welcome to LXQt</source>
-        <translation type="vanished">Bonvenon en LXQt</translation>
+        <translation>Bonvenon en LXQt</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Welcome to LXQt&lt;/b&gt;
-&lt;p&gt;
-Before starting to use the LXQt, you might want to select the Windows Manager:</source>
-        <translation type="vanished">&lt;b&gt;Bonvenon en LXQt&lt;/b&gt;
-&lt;p&gt;
-Antaŭ startigi uzadon de LXQt, vi eble volas elekti la fenestran mastrumilon:</translation>
-    </message>
-    <message>
-        <source>You can change the Window Manager later at any time via LxQt Session Configurator.</source>
-        <translation type="vanished">Vi povas ŝanĝi la fenestran mastrumilon poste iam ajn per la agordilo de seanco de LxQt.</translation>
-    </message>
-    <message>
-        <location filename="../src/wmselectdialog.cpp" line="62"/>
+        <location filename="../src/wmselectdialog.cpp" line="65"/>
         <source>Other ...</source>
         <translation>Alia...</translation>
     </message>
     <message>
-        <location filename="../src/wmselectdialog.cpp" line="63"/>
+        <location filename="../src/wmselectdialog.cpp" line="66"/>
         <source>Choose your favorite one.</source>
         <translation>Elektu vian preferatan fenestran mastrumilon.</translation>
     </message>
-    <message>
-        <location filename="../src/wmselectdialog.ui" line="14"/>
-        <source>Welcome to LXQt</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../src/wmselectdialog.ui" line="20"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Welcome to LXQt&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Please select your default Window Manager.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
